soccer
======

.. image:: https://img.shields.io/pypi/v/soccer.svg
    :target: https://pypi.python.org/pypi/soccer
    :alt: Latest PyPI version

.. image:: https://travis-ci.org/hhllcks/soccer.png
   :target: https://travis-ci.org/hhllcks/soccer
   :alt: Latest Travis CI build status

A soccer data framework

Usage
-----

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

`soccer` was written by `Hendrik Hilleckes <hhllcks@gmail.com>`_.
